==> mmoo_base-1.2.0%2B1.tar.gz: lib/ui/button_click_widget.dart <==
import 'package:flutter/material.dart';
import 'package:mmoo_base/utils/navigator_utils.dart';

///按钮点击样式切换
class ButtonClickWidget extends StatefulWidget {
  final String imageNormal;
  final String imageClick;
  final String imageUn;
  final double width;
  final double height;
  final Widget? child;
  final Widget? child2;
  final double? top;
  final double? top2;
  final Function? click;

  const ButtonClickWidget(
      this.imageNormal, this.imageClick, this.imageUn, this.width, this.height,
      {Key? key, this.child, this.child2, this.click, this.top, this.top2})
      : super(key: key);

  @override
  ButtonClickWidgetState createState() => ButtonClickWidgetState();
}

class ButtonClickWidgetState extends State<ButtonClickWidget> {
  bool clickImage = false;
  bool enabledImage = true;
  int clickTime = 0;

  void setEnabledImage(bool enabled) {
    if (enabledImage != enabled) {
      enabledImage = enabled;
      setState(() {});
    }
  }

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      child: widget.child != null
          ? Stack(
              alignment: Alignment.center,
              children: [
                Image.asset(
                    !enabledImage
                        ? widget.imageUn
                        : clickImage
                            ? widget.imageClick
                            : widget.imageNormal,
                    fit: BoxFit.fill,
                    width: widget.width,
                    height: widget.height),
                Positioned(
                    top: clickImage ? widget.top2 : widget.top,
                    child: widget.child!),
                widget.child2 != null
                    ? Positioned(
                        top: clickImage ? widget.top2 : widget.top,
                        child: widget.child2!)
                    : Container()
              ],
            )
          : Image.asset(
              !enabledImage
                  ? widget.imageUn
                  : clickImage
                      ? widget.imageClick
                      : widget.imageNormal,
              fit: BoxFit.fill,
              width: widget.width,
              height: widget.height),
      onTapDown: (TapDownDetails details) {
        if (!enabledImage) {
          return;
        }
        clickImage = true;
        clickTime = DateTime.now().millisecondsSinceEpoch;
        setState(() {});
      },
      onTapUp: (TapUpDetails details) {
        if (!enabledImage) {
          return;
        }
        if (DateTime.now().millisecondsSinceEpoch - clickTime >= 200) {
          clickImage = false;
          setState(() {});
        } else {
          Future.delayed(Duration(milliseconds: 200), () {
            if (!mounted) return;
            clickImage = false;
            setState(() {});
          });
        }
      },
      onTapCancel: () {
        if (!enabledImage) {
          return;
        }
        if (DateTime.now().millisecondsSinceEpoch - clickTime >= 200) {
          clickImage = false;
          setState(() {});
        } else {
          Future.delayed(Duration(milliseconds: 200), () {
            if (!mounted) return;
            clickImage = false;
            setState(() {});
          });
        }
      },
      onTap: NavigatorUtils.debounce(() {
        if (!enabledImage) {
          return;
        }
        widget.click?.call();
      }),
    );
  }
}

==> mmoo_base-1.3.0%2B1.tar.gz: lib/ui/button_click_widget.dart <==
import 'package:flutter/material.dart';
import 'package:mmoo_base/utils/common_utils.dart';
import 'package:mmoo_base/utils/navigator_utils.dart';

///按钮点击样式切换
class ButtonClickWidget extends StatefulWidget {
  final String imageNormal;
  final String imageClick;
  final String imageUn;
  final double width;
  final double height;
  final Widget? child;
  final Widget? child2;
  final double? top;
  final double? top2;
  final Function? click;
  final String imageIcon;
  final String imageUrl;
  final String load;
  final Color colorBg;
  final Color colorProgress;

  const ButtonClickWidget(
      this.imageNormal,
      this.imageClick,
      this.imageUn,
      this.width,
      this.height,
      this.imageIcon,
      this.imageUrl,
      this.load,
      this.colorBg,
      this.colorProgress,
      {Key? key,
      this.child,
      this.child2,
      this.click,
      this.top,
      this.top2})
      : super(key: key);

  @override
  ButtonClickWidgetState createState() => ButtonClickWidgetState();
}

class ButtonClickWidgetState extends State<ButtonClickWidget> {
  bool clickImage = false;
  bool enabledImage = true;
  int clickTime = 0;

  void setEnabledImage(bool enabled) {
    if (enabledImage != enabled) {
      enabledImage = enabled;
      setState(() {});
    }
  }

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      child: widget.child != null
          ? Stack(
              alignment: Alignment.center,
              children: [
                CommonUtils.getLoadWidget(
                    !enabledImage
                        ? widget.imageUn
                        : clickImage
                            ? widget.imageClick
                            : widget.imageNormal,
                    widget.imageIcon,
                    widget.imageUrl,
                    widget.load,
                    widget.colorBg,
                    widget.colorProgress,
                    fit: BoxFit.fill,
                    width: widget.width,
                    height: widget.height),
                Positioned(
                    top: clickImage ? widget.top2 : widget.top,
                    child: widget.child!),
                widget.child2 != null
                    ? Positioned(
                        top: clickImage ? widget.top2 : widget.top,
                        child: widget.child2!)
                    : Container()
              ],
            )
          : CommonUtils.getLoadWidget(
              !enabledImage
                  ? widget.imageUn
                  : clickImage
                      ? widget.imageClick
                      : widget.imageNormal,
              widget.imageIcon,
              widget.imageUrl,
              widget.load,
              widget.colorBg,
              widget.colorProgress,
              fit: BoxFit.fill,
              width: widget.width,
              height: widget.height),
      onTapDown: (TapDownDetails details) {
        if (!enabledImage) {
          return;
        }
        clickImage = true;
        clickTime = DateTime.now().millisecondsSinceEpoch;
        setState(() {});
      },
      onTapUp: (TapUpDetails details) {
        if (!enabledImage) {
          return;
        }
        if (DateTime.now().millisecondsSinceEpoch - clickTime >= 200) {
          clickImage = false;
          setState(() {});
        } else {
          Future.delayed(const Duration(milliseconds: 200), () {
            if (!mounted) return;
            clickImage = false;
            setState(() {});
          });
        }
      },
      onTapCancel: () {
        if (!enabledImage) {
          return;
        }
        if (DateTime.now().millisecondsSinceEpoch - clickTime >= 200) {
          clickImage = false;
          setState(() {});
        } else {
          Future.delayed(const Duration(milliseconds: 200), () {
            if (!mounted) return;
            clickImage = false;
            setState(() {});
          });
        }
      },
      onTap: NavigatorUtils.debounce(() {
        if (!enabledImage) {
          return;
        }
        widget.click?.call();
      }),
    );
  }
}
